<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local plugin "dashboard" - Settings
 *
 * @package    local_dashboard
 * @copyright   2015 KTree Computer Solutions <opensource@ktree.com>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once(dirname(dirname(dirname(__FILE__))).'/config.php');
require_once($CFG->dirroot . '/local/dashboard/lib.php');
redirect_if_major_upgrade_required();
$edit   = optional_param('edit', null, PARAM_BOOL);
require_login();
$strmymoodle = 'Dashboard';
if (!isguestuser()) {
    $userid = $USER->id;
    $context = context_user::instance($USER->id);
    $PAGE->set_blocks_editing_capability('moodle/my:manageblocks');
    $header = "$strmymoodle";
}

$context = context_user::instance($USER->id);

$roles = get_user_roles($context, $USER->id, true);
$flag = 0;
foreach ($roles as $key => $value) 
{
    if($value->shortname == 'staffteacher')
    {
        $flag = 1;
        break;
    }
    if($value->shortname == 'manager')
    {
        $flag = 2;
        break;
    }
}

$params = array();
$PAGE->set_context($context);
// $PAGE->set_url('/local/dashboard/index.php', $params);
$PAGE->set_pagelayout('mydashboard');
$PAGE->set_pagetype('my-index');
$PAGE->blocks->add_region('content');

$PAGE->set_title($header);
$PAGE->set_heading($header);
if (!isguestuser()) {
    if (get_home_page() != HOMEPAGE_MY) {
        if (optional_param('setdefaulthome', false, PARAM_BOOL)) {
            set_user_preference('user_home_page_preference', HOMEPAGE_MY);
        } else if (!empty($CFG->defaulthomepage) && $CFG->defaulthomepage == HOMEPAGE_USER) {
            $PAGE->settingsnav->get('usercurrentsettings')->add(get_string('makethismyhome'), new moodle_url('/my/',
            array('setdefaulthome' => true)), navigation_node::TYPE_SETTING);
        }
    }
}
echo $OUTPUT->header();
$enrolresults = enrol_get_my_courses('summary', 'visible DESC,sortorder ASC');
if($flag == 2)
    $enrolresults = $DB->get_records_sql("SELECT DISTINCT c.id FROM mdl_course AS c INNER JOIN mdl_context AS cx ON c.id = cx.instanceid AND cx.contextlevel = '50'");
else
    $enrolresults = $DB->get_records_sql("SELECT DISTINCT c.id, usr.username,r.shortname as role_to FROM mdl_course AS c INNER JOIN mdl_context AS cx ON c.id = cx.instanceid AND cx.contextlevel = '50' INNER JOIN mdl_role_assignments AS ra ON cx.id = ra.contextid INNER JOIN mdl_role AS r ON ra.roleid = r.id INNER JOIN mdl_user AS usr ON ra.userid = usr.id where ra.userid=".$USER->id);
$coursesarray = array();
foreach ($enrolresults as $enrol) {
    $coursesarray[] = $enrol->id;
}
// echo '<pre>';
// var_dump($enrolresults);

$courses = implode(",", $coursesarray);
$flag_2 = 0;
echo '<h3 style="text-align:center;">Quiz For Me</h3>';
$course_cs = array();
if ($courses != null) {
    $moddetails = $DB->get_records_sql("select id ,name from {modules}");
    $table = "<table class='generaltable'><tr><th> ".get_string('tblheadcoursename',
    'local_dashboard')."</th><th> ".get_string('tblheadmodulename', 'local_dashboard')."</th></tr>";
    foreach ($moddetails as $modkey => $modval) {
        $param['moduleid'] = $modval->id;
        $sqlquery = "SELECT a.name AS name,a.course AS courseid,cm.id AS id,cs.fullname AS cfname,cs.shortname AS csname
                     FROM {course} cs join {".$modval->name."} a
					      ON cs.id=a.course JOIN {course_modules} cm
						  ON a.course= cm.course AND a.id=cm.instance
						  WHERE cm.module = :moduleid AND a.course
						  IN($courses)";


      
       $mod = $DB->get_records_sql($sqlquery , $param);
        if ($mod != null) {
            $flag_2 = 1;
            // if($modval->name == 'assign')
                // $table .= "<tr><td colspan=2 align=center><b>".ucfirst($modval->name)."</b></td></tr>";
            // echo $modval->name;
            foreach ($mod as $name => $val) {
                // echo '<pre>';
                // var_dump($val);die;
                if($modval->name == 'quiz')
                {
                    $course_cs[$val->cfname] = $val->courseid;
                    $table .= '<tr class="c_'.$val->courseid.' all_cour"><td><a class = "dashboardlink" href="'.
                    $url = new moodle_url('/course/view.php' , array('id' => $val->courseid)).'">'.
                    $val->cfname.'</a></td>';
                    $table .= '<td><a class = "dashboardlink" href = "'.
                    $url = new moodle_url('/mod/'.$modval->name.'/view.php' , array('id' => $val->id)).'">'.
                    $val->name.'</a></td>';
                    // $table .= '<td align = "center"><a class = "dashboardlink" href = "'.
                    // $url = new moodle_url('/mod/'.$modval->name.'/view.php' , array('id' => $val->id,'action'=>'editsubmission')).'">Submit</a></td></tr>';
                }
            }
        }
    }
    $table .= "</table>";
}
if ($flag_2 == 0) {
    echo get_string('noactivities', 'local_dashboard');
} 
    if(!empty($course_cs))
    {
        $sel_str = '<div class="header"><label class="m-r-1" for="course">Quiz for:</label><select class="select custom-select cal_courses_flt" id="cour_filter" onchange="sel_change()"><option value="0">All course</option>';
        foreach ($course_cs as $key => $value) 
        {
           $sel_str .= '<option value="'.$value.'">'.$key.'</option>';
        }
        $sel_str .= '</select></div>';
        echo $sel_str;
        $sel_js = '<script>function sel_change(){var el_val = jQuery("#cour_filter").val();if(el_val == "0"){ jQuery(".all_cour").show();} else {jQuery(".all_cour").hide();jQuery(".c_"+el_val).show();}}</script>';
        echo $sel_js;
    }
    echo $table;
    

    if($flag == 1 || $flag == 2)
    {
        echo '<div><a href="'.$CFG->wwwroot.'/local/dashboard/addquiz.php" class="btn btn-primary">Add Quiz</a></div>';
    }

echo $OUTPUT->footer();
