<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * myprofile renderer.
 *
 * @package    core_user
 * @copyright  2015 onwards Ankit Agarwal <ankit.agrr@gmail.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace core_user\output\myprofile;
defined('MOODLE_INTERNAL') || die;
/**
 * Report log renderer's for printing reports.
 *
 * @since      Moodle 2.9
 * @package    core_user
 * @copyright  2015 onwards Ankit Agarwal <ankit.agrr@gmail.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class renderer extends \plugin_renderer_base {
    /**
     * Render the whole tree.
     *
     * @param tree $tree
     *
     * @return string
     */
    public $nn = 0;
    public $ll = 0;
    public $cat_name = 'Basic';
    public $cat_name_l = '';
    public $user_type = 'Student';
    public $fl = 0;

    public function render_tree(tree $tree) {
        $return = \html_writer::start_tag('div', array('class' => 'profile_tree'));
        $categories = $tree->categories;
        foreach ($categories as $category) {
            $return .= $this->render($category);
        }
        $return .= \html_writer::end_tag('div');
        return $return;
    }

    /**
     * Render a category.
     *
     * @param category $category
     *
     * @return string
     */
    public function render_category(category $category) {
        $classes = $category->classes;
        if (empty($classes)) {
            $return = \html_writer::start_tag('section', array('class' => 'node_category'));
        } else {
            $return = \html_writer::start_tag('section', array('class' => 'node_category ' . $classes));
        }
        $return .= \html_writer::tag('h3', $category->title);
        $nodes = $category->nodes;
        if (empty($nodes)) {
            // No nodes, nothing to render.
            return '';
        }
        $return .= \html_writer::start_tag('ul');
        foreach ($nodes as $node) {
            $return .= $this->render($node);
        }
        $return .= \html_writer::end_tag('ul');
        $return .= \html_writer::end_tag('section');
        return $return;
    }

    /**
     * Render a node.
     *
     * @param node $node
     *
     * @return string
     */
    public function render_node(node $node) {
        global $CFG;
        if($this->nn == 0){
            echo '<div class="abc"><h3>User Details</h3>';
            echo '<a class="edit_btn" style="float:right;" href="'.$CFG->wwwroot.'/user/edit.php?id='.optional_param('id', 0, PARAM_INT).'&returnto=profile">Edit profile</a>';
            // echo '<section class="node_category">';
            $this->nn = 1;
        }
        $return = '';
        if (is_object($node->url)) {
            $header = \html_writer::link($node->url, $node->title);
        } else {
            $header = $node->title;
        }
        $icon = $node->icon;
        if (!empty($icon)) {
            $header .= $this->render($icon);
        }
        $content = $node->content;
        $classes = $node->classes;
        if (!empty($content)) 
        {
            if($node->parentcat == 'contact')
            {
                global $DB;
                $query = "SELECT * FROM mdl_user_info_category ORDER BY sortorder ASC";
                $cat_array = $DB->get_records_sql($query);
                $cat_ass_arr = array();
                foreach ($cat_array as $key => $value) 
                {
                    $cat_ass_arr[$value->id] = $value->name;
                }
                $temp = explode("_", $node->name);
                if(count($temp) > 2){
                    unset($temp[0]);
                    unset($temp[1]);
                }
                $cond_name = implode("_", $temp);

                $query1 = "SELECT categoryid FROM mdl_user_info_field WHERE shortname='".$cond_name."'";
                $cat_info = $DB->get_record_sql($query1);
                
                // $cat_name = '';
                // $cat_name_l = '';
                if(!empty($cat_info) && !empty($cat_info->categoryid))
                {
                    $this->cat_name = $cat_ass_arr[$cat_info->categoryid];
                }
                
                
                if($this->cat_name_l != $this->cat_name)
                {
                    if($this->cat_name == 'User Type')
                    {
                        $this->user_type = $node->content;
                    }
                    if($this->user_type == 'Student')
                    {
                        if($this->cat_name != 'Teacher Profile Fields')
                        {    
                            if($this->cat_name != 'User Type' && $this->cat_name != 'Basic')
                            {            
                                $this->cat_name_l = $this->cat_name;
                                echo '<h4 style="margin-top:15px !important;">'.$this->cat_name.'</h4>';
                            }
                        }
                        
                    }
                    else if($this->user_type == 'Teacher')
                    {
                        if($this->cat_name == 'Teacher Profile Fields')
                        {                      
                            $this->cat_name_l = $this->cat_name;
                            echo '<h4 style="margin-top:15px !important;">'.$this->cat_name.'</h4>';
                        }
                        
                    }
                    else
                    {
                    	if($this->cat_name != 'Teacher Profile Fields' && $this->cat_name != 'Personal' && $this->cat_name != 'Identification' && $this->cat_name != 'Education')
                    	{
	                    	$this->cat_name_l = $this->cat_name;
	                        echo '<h4 style="margin-top:15px !important;">'.$this->cat_name.'</h4>';
	                    }
                    }
                    
                    
                }

                if($this->cat_name == 'User Type' && $node->content == 'Student')
                {
                    if($this->ll == 0){
                        echo '<style>.edit_btn{display:none;}</style>';
                        $this->ll = 1;
                    }
                }
                // else
                // {
                // 	if($this->ll == 0){
                //         echo '<style>.edit_btn{display:block;}</style>';
                //         $this->ll = 1;
                //     }
                // }

                // echo $this->user_type;

                if($this->user_type == 'Student')
                {

                    if($this->cat_name == 'User Type')
                    {
                        $this->user_type = $node->content;
                    }
                    if($this->cat_name != 'Teacher Profile Fields')
                    {              
                        if($this->cat_name != 'User Type' && $this->cat_name != 'Basic')
                        {          
                            echo '<div style="font-weight:bold;margin-top:5px;">'.$node->title.'</div>';
                            echo '<div style="margin-left:10px;font-weight:normal;">'.$node->content.'</div>';
                        }
                    }
                    // var_dump($node);
                    // if($node->title == 'Semester Form')
                    // {
                    //     echo '<a href="'.$CFG->wwwroot.'/local/simple_contact_form/" style="margin-top:20px;" class="btn btn-primary">Self Service</a>';
                    //     echo '</div>';
                    // }
                }
                else if($this->user_type == 'Teacher')
                {
                    if($this->cat_name == 'User Type')
                    {
                        $this->user_type = $node->content;

                    }
                    if($this->cat_name == 'Teacher Profile Fields')
                    {   
                        if($this->cat_name != 'User Type' && $this->cat_name != 'Basic')
                        {                     
                            echo '<div style="font-weight:bold">'.$node->title.'</div>';
                            echo '<div>'.$node->content.'</div>';
                        }
                    }

                    // if($node->title == 'Zipcode')
                    // {
                    //     echo '<a href="'.$CFG->wwwroot.'/enrol/apply/manage.php" style="margin-top:20px;" class="btn btn-primary">Enrollment Requests</a>';
                    //     echo '</div>';
                    // }
                    
                }
                else
                {
                	
                    if($this->cat_name == 'User Type')
                    {
                        $this->user_type = $node->content;

                    }
                    if($this->cat_name != 'Teacher Profile Fields' && $this->cat_name != 'Personal' && $this->cat_name != 'Identification' && $this->cat_name != 'Education')
                    {   
                        echo '<div style="font-weight:bold">'.$node->title.'</div>';
                        echo '<div>'.$node->content.'</div>';
                    }

                    // if($node->title == 'User Type')
                    // {
                    // 	echo '<a href="'.$CFG->wwwroot.'/local/simple_contact_form/request_list.php" style="margin:20px;" class="btn btn-primary">Self Service Requests</a>';
                    //     echo '<a href="'.$CFG->wwwroot.'/enrol/apply/manage.php" style="margin:20px;" class="btn btn-primary">Enrollment Requests</a>';
                    //     echo '</div>';
                    // }
                    
                }
            }
            else
            {
                if(!is_siteadmin())
                {
                    if($this->fl == 0)
                    {
                        if($this->user_type == 'Student')
                        {
                            $this->fl = 1;
                            echo '<a href="'.$CFG->wwwroot.'/local/simple_contact_form/" style="margin-top:20px;" class="btn btn-primary">Self Service</a>';
                            echo '</div>';

                        }
                        else if($this->user_type == 'Teacher')
                        {
                            $this->fl = 1;
                            echo '<a href="'.$CFG->wwwroot.'/enrol/apply/manage.php" style="margin-top:20px;" class="btn btn-primary">Enrollment Requests</a>';
                                echo '</div>';
                        }
                        else
                        {
                            $this->fl = 1;
                            // echo '<a href="'.$CFG->wwwroot.'/local/simple_contact_form/request_list.php" style="margin:20px;" class="btn btn-primary">Self Service Requests</a>';
                            // echo '<a href="'.$CFG->wwwroot.'/enrol/apply/manage.php" style="margin:20px;" class="btn btn-primary">Enrollment Requests</a>';
                            echo '</div>';
                        }
                    }
                }
                else
                {
                    if($this->fl == 0)
                    {
                        $this->fl = 1;
                        echo '</div>';
                    }
                }
                
               
                // There is some content to display below this make this a header.
                // var_dump($header);
                $return = \html_writer::tag('dt', $header);
                $return .= \html_writer::tag('dd', $content);

                $return = \html_writer::tag('dl', $return);
                if ($classes) {
                    $return = \html_writer::tag('li', $return, array('class' => 'contentnode ' . $classes));
                } else {
                    $return = \html_writer::tag('li', $return, array('class' => 'contentnode'));
                }
            }
        } else {
            $return = \html_writer::span($header);
            $return = \html_writer::tag('li', $return, array('class' => $classes));
        }

        return $return;
    }
}
